@@ -757,7 +757,10 @@ class SchemeEditWidget(QWidget):
 
         """
         if title is None:
-            title = self.enumerateTitle(description.name)
+            change_title = QSettings().value("oasys/change_title_on_new_duplicate", 0, int) == 1
+
+            if change_title: title = self.enumerateTitle(description.name)
+            else: title = description.name
 
         if position is None:
             position = self.nextPosition()
@@ -1580,9 +1583,9 @@ class SchemeEditWidget(QWidget):
                     link.sink_node in selection]
         nodedups = [copy_node(node) for node in selection]
 
-        change_title = QSettings().value("oasys/change_title_on_duplicate", 0, int)
+        change_title = QSettings().value("oasys/change_title_on_new_duplicate", 0, int) == 1
 
-        if change_title == 1:
+        if change_title:
             allnames = {node.title for node in scheme.nodes + nodedups}
             for nodedup in nodedups:
                 nodedup.title = uniquify(
